@@ -6,7 +6,7 @@ package Xen::Tools::Common;
 
 =head1 NAME
 
-Xen::Tools::Common - Common funtions used in xen-tools' Perl scripts
+Xen::Tools::Common - Common functions used in xen-tools' Perl scripts
 
 
 =head1 SYNOPSIS
@@ -70,7 +70,7 @@ sub readConfigurationFile ($$)
         next if ( length($line) < 1 );
 
         # Strip trailing comments.
-        if ( $line =~ /(.*)\#(.*)/ )
+        if ( $line =~ /([^#]*)\#(.*)/ )
         {
             $line = $1;
         }
@@ -129,7 +129,8 @@ sub xenRunning ($$)
     my $running = 0;
 
     unless ($CONFIG->{'xm'}) {
-        warn "Couldn't determine Xen toolstack, skipping check for running DomUs.";
+        warn "Couldn't determine Xen toolstack, skipping check for running DomUs."
+            unless $ENV{AS_INSTALLED_TESTING};
         return 0;
     }
 
@@ -245,7 +246,8 @@ sub runCommand ($$;$)
 
     if (!$rcclose)
     {
-        logprint_with_config("Running command '$cmd' failed with exit code $?.\n", $CONFIG);
+        my $exit_code = $? >> 8;
+        logprint_with_config("Running command '$cmd' failed with exit code $exit_code.\n", $CONFIG);
         logprint_with_config("Aborting\n", $CONFIG);
         print "See /var/log/xen-tools/".$CONFIG->{'hostname'}.".log for details\n";
         unless ($fail_ok) {
@@ -405,9 +407,9 @@ sub logprint_with_config ($$)
 
 =head1 AUTHORS
 
- Steve Kemp, http://www.steve.org.uk/
- Axel Beckert, http://noone.org/abe/
- Dmitry Nedospasov, http://nedos.net/
+ Steve Kemp, https://steve.fi/
+ Axel Beckert, https://axel.beckert.ch/
+ Dmitry Nedospasov, http://www.nedos.net/
  Stéphane Jourdois
 
  Merged from several scripts by Axel Beckert.
